// form_methods.js - Created by James A. Pattie <james@pcxperience.com>
// 2003-08-18.  Copyright (c) 2003 by Xperience, Inc. (http://www.pcxperience.com/)
//
// This JS script will contain functions that provide functionality needed by
// webpages dealing with forms.

function selectAll(widget)
{
  if (widget.options)
  {
    for (var i=0; i < widget.options.length; i++)
    {
      widget.options[i].selected = true;
    }
  }
  else
  {
    alert("selectAll called with a non-select form widget!  widget='" + widget.toString() + "'");
  }
}

function unSelectAll(widget)
{
  if (widget.options)
  {
    for (var i=0; i < widget.options.length; i++)
    {
      widget.options[i].selected = false;
    }
  }
  else
  {
    alert("unSelectAll called with a non-select form widget!  widget='" + widget.toString() + "'");
  }
}

function getTimeStamp()
{
  var timeStamp = new Date();
  return timeStamp.getTime();
}

// returns a boolean value to say if the html form item contains a valid color.
function isValidColor(widget)
{
  var colorMask = /^((#([A-F]|[0-9]){6})|transparent|inherit)( !important)?$/;
  var result = widget.value.match(colorMask);
  if (result == null)
  {
    return false;  // invalid
  }
  return true;  // valid
}

// returns a boolean value to indicate if the html form item contains a valid ISO Date,
// seperated by the specified value that can be - \ or /.
function isValidDate(widget, seperator)
{
  var seperators = new RegExp("[\-\\\/]");
  var seperatorReg = "\\" + seperator;
  // make sure the seperator is one of the allowed values.
  if (!seperators.test(seperator))
  {
    alert("isValidDate: seperator='" + seperator + "' is invalid!");
    return false;
  }
  var dateMask = new RegExp("^(\d{4}" + seperatorReg + "\d{2}" + seperatorReg + "\d{2})$");
  var result = widget.value.match(dateMask);
  if (result == null)
  {
    return false;  // invalid
  }
  return true;  // valid
}

// formatDateNumber makes sure that the result is 0 prefixed.
function formatDateNumber(value)
{
  if (value.length == 1)
  {
    value = "0" + value;
  }

  return value;
}

// this function will attempt to fixup a date to be ISO format
// returns true if the date was able to be fixed up,
// returns false if the date was invalid and could not be fixed.
function fixupDate(widget, seperator, year)
{
  var seperators = new RegExp("[\-\\\/]", "g");
  var yearReg = /^(\d{4})$/;

  // make sure the seperator is one of the allowed values.
  if (!seperators.test(seperator))
  {
    alert("fixupDate: seperator='" + seperator + "' is invalid!");
    return false;
  }
  if (!yearReg.test(year))
  {
    alert("fixupDate: year='" + year + "' is invalid!");
    return false;
  }
  if (!isValidDate(widget, seperator))
  {
    var str = widget.value;

    // replace any non digit/seperator characters with nothing.
    var illegalChar = new RegExp("[^0-9\-\\\/]", "g");
    str = str.replace(illegalChar, "");

    if (str.length == 0)
    {
      alert("fixupDate: Date='" + widget.value + "' is invalid!");
      widget.value = str;  // make sure that we update the edit field to potentially remove any invalid chars.
      return false;
    }

    // fixup all seperators to be -.
    str = str.replace(seperators, seperator);
    //alert("Fixed up '" + widget.value + "' to be '" + str + "'");

    // update the date the user sees.
    widget.value = str;

    var digits = str.split("-");
    // figure out what we have to work with.
    if (digits.length == 0)
    {
      alert("fixupDate: Date='" + str + "' has no " + seperator + " seperators!");
      return false;
    }
    else if (digits.length > 3)
    {
      alert("fixupDate: Date='" + str + "' has more than 2 " + seperator + " seperators!");
      return false;
    }
    else if (digits.length == 1)
    {
      alert("fixupDate: Date='" + str + "' does not have enough data to work with!");
      return false;
    }
    else if (digits.length == 2)
    {
      // make sure we have 2, 2 or 1 digit values which we can then fixup and tack the year on.
      if (digits[0].length > 2)
      {
        alert("fixupDate: Date='" + str + "' does not have a month part!");
        return false;
      }
      if (digits[1].length > 2)
      {
        alert("fixupDate: Date='" + str + "' does not have a day part!");
        return false;
      }
      str = year + seperator + formatDateNumber(digits[0]) + seperator + formatDateNumber(digits[1]);
    }
    else if (digits.length == 3)
    {
      // make sure it is year, month, day
      if (digits[0].length <= 2 && digits[1].length <= 2 && digits[2].length == 4)
      {
        str = digits[2] + seperator + formatDateNumber(digits[0]) + seperator + formatDateNumber(digits[1]);
      }
      else
      {
        if (digits[0].length == 4)
        {
          if (digits[1].length > 2 || digits[2].length > 2)
          {
            alert("fixupDate: Date='" + str + "' is invalid!");
            return false;
          }
          else
          {
            str = digits[0] + seperator + formatDateNumber(digits[1]) + seperator + formatDateNumber(digits[2]);
          }
        }
      }
    }

    // update the date before returning.
    widget.value = str;
  }

  return true;
}
